summaryrefslogtreecommitdiffstats
path: root/chrome/browser/io_thread.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/io_thread.cc')
-rw-r--r--chrome/browser/io_thread.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/io_thread.cc b/chrome/browser/io_thread.cc
index 13adde9..c451b25 100644
--- a/chrome/browser/io_thread.cc
+++ b/chrome/browser/io_thread.cc
@@ -139,9 +139,9 @@ void IOThread::Init() {
void IOThread::CleanUp() {
// If any child processes are still running, terminate them and
// and delete the ChildProcessHost instances to release whatever
// IO thread only resources they are referencing.
- ChildProcessHost::TerminateAll();
+ BrowserChildProcessHost::TerminateAll();
// Not initialized in Init(). May not be initialized.
if (predictor_) {
@@ -139,9 +139,9 @@ void IOThread::Init() {
void IOThread::CleanUp() {
// If any child processes are still running, terminate them and
- // and delete the ChildProcessHost instances to release whatever
+ // and delete the BrowserChildProcessHost instances to release whatever
// IO thread only resources they are referencing.